/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { LocalizedMessagesDirective } from "./localization/localized-messages.directive";
import { PopoverAnchorDirective } from "./popover/anchor.directive";
import { PopoverContainerDirective } from "./popover/container.directive";
import { PopoverComponent } from "./popover/popover.component";
import { PopoverActionsTemplateDirective } from "./popover/template-directives/actions-template.directive";
import { PopoverBodyTemplateDirective } from "./popover/template-directives/body-template.directive";
import { PopoverTitleTemplateDirective } from "./popover/template-directives/title-template.directive";
import { TooltipContentComponent } from "./tooltip/tooltip.content.component";
import { TooltipDirective } from "./tooltip/tooltip.directive";
/**
 * Use this utility array to access all Tooltip-related components and directives in a standalone Angular component.
 *
 * @example
 * ```typescript
 * import { Component } from '@angular/core';
 * import { KENDO_TOOLTIP } from '@progress/kendo-angular-tooltip';
 *
 * @Component({
 *   selector: 'my-app',
 *   standalone: true,
 *   imports: [KENDO_TOOLTIP],
 *   template: `
 *      <div kendoTooltip>
 *          <button kendoButton title="Save">Save</button>
 *      </div>
 *   `
 * })
 * export class AppComponent {}
 * ```
 */
export const KENDO_TOOLTIP = [
    TooltipDirective,
    TooltipContentComponent,
    LocalizedMessagesDirective
];
/**
 * Use this utility array to access all Popover-related components and directives in a standalone Angular component.
 *
 * @example
 * ```typescript
 * import { Component } from '@angular/core';
 * import { KENDO_POPOVER } from '@progress/kendo-angular-tooltip';
 *
 * @Component({
 *   selector: 'my-app',
 *   standalone: true,
 *   imports: [KENDO_POPOVER],
 *   template: `
 *      <div kendoPopoverAnchor [popover]="myPopover">
 *          <button kendoButton>Open Popover</button>
 *      </div>
 *      <kendo-popover #myPopover title="Popover Title" body="Popover Body">
 *      </kendo-popover>
 *   `
 * })
 * export class AppComponent {}
 * ```
 */
export const KENDO_POPOVER = [
    PopoverComponent,
    PopoverActionsTemplateDirective,
    PopoverBodyTemplateDirective,
    PopoverTitleTemplateDirective,
    PopoverAnchorDirective,
    PopoverContainerDirective
];
/**
 * Use this utility array to access all `@progress/kendo-angular-tooltip`-related components and directives in a standalone Angular component.
 *
 * @example
 * ```typescript
 * import { Component } from '@angular/core';
 * import { KENDO_TOOLTIPS } from '@progress/kendo-angular-tooltip';
 *
 * @Component({
 *   selector: 'my-app',
 *   standalone: true,
 *   imports: [KENDO_TOOLTIPS],
 *   template: `
 *      <div kendoTooltip>
 *          <button kendoButton title="Save">Save</button>
 *      </div>
 *
 *      <div kendoPopoverAnchor [popover]="myPopover">
 *          <button kendoButton>Open Popover</button>
 *      </div>
 *      <kendo-popover #myPopover title="Popover Title" body="Popover Body">
 *      </kendo-popover>
 *  `
 * })
 * export class AppComponent {}
 * ```
 */
export const KENDO_TOOLTIPS = [
    ...KENDO_TOOLTIP,
    ...KENDO_POPOVER
];
