/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { PreventableEvent } from "@progress/kendo-angular-common";
/**
 * Provides arguments for the `show` event. The event fires when a popover is about to open. Cancel the event to prevent opening.
 */
export class PopoverShowEvent extends PreventableEvent {
    /**
     * Specifies the host element related to the Popover.
     */
    anchor;
    /**
     * @hidden
     * Constructs the event arguments for the `show` event.
     * @param anchor - The host element related to the Popover.
     */
    constructor(anchor) {
        super();
        this.anchor = anchor;
    }
}
/**
 * Provides arguments for the `hide` event. The event fires when a popover is about to close. Cancel the event to keep it open.
 */
export class PopoverHideEvent extends PreventableEvent {
    /**
     * Specifies the host element related to the Popover.
     */
    anchor;
    /**
     * Specifies the Popover element.
     */
    popover;
    /**
     * @hidden
     * Constructs the event arguments for the `hide` event.
     * @param anchor - The host element related to the popover.
     * @param popover - The popover element.
     */
    constructor(anchor, popover) {
        super();
        this.anchor = anchor;
        this.popover = popover;
    }
}
/**
 * Provides arguments for the `shown` event. The event fires after the Popover has opened and its opening animation has finished.
 */
export class PopoverShownEvent {
    /**
     * Specifies the host element related to the Popover.
     */
    anchor;
    /**
     * Specifies the Popover element.
     */
    popover;
    /**
     * @hidden
     * Constructs the event arguments for the `shown` event.
     * @param anchor - The host element related to the popover.
     * @param popover - The popover element.
     */
    constructor(anchor, popover) {
        this.anchor = anchor;
        this.popover = popover;
    }
}
/**
 * Provides arguments for the `hidden` event. The event fires after the popover has closed and its closing animation has finished.
 */
export class PopoverHiddenEvent {
    /**
     * Specifies the host element related to the Popover.
     */
    anchor;
    /**
     * @hidden
     * Constructs the event arguments for the `hidden` event.
     * @param anchor - The host element related to the popover.
     */
    constructor(anchor) {
        this.anchor = anchor;
    }
}
