/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Injectable, InjectionToken } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Obsolete. Provide the TooltipSettings class instead.
 *
 * @hidden
 */
export const TOOLTIP_SETTINGS = new InjectionToken('kendo-ui-tooltip-settings');
/**
 * Provides a global configuration for the Kendo UI Tooltip. Inject this class in the `AppComponent` constructor to override configuration properties.
 *
 * @example
 * ```typescript
 * import { TooltipSettings } from '@progress/kendo-angular-tooltip';
 *
 * @Component({
 *   selector: 'my-app',
 *   template: `<div kendoTooltip><button title="Save">Save</button></div>`,
 *   providers: [{
 *     provide: TooltipSettings,
 *     useFactory: (): TooltipSettings => ({ position: 'right' })
 *   }]
 * })
 * export class AppComponent {}
 * ```
 */
export class TooltipSettings {
    /**
     * Determines if the Tooltip displays a callout arrow.
     *
     * @default true
     */
    callout;
    /**
     * Sets the title of the **Close** button.
     */
    closeTitle;
    /**
     * Specifies the position of the Tooltip relative to the anchor element.
     *
     * @default 'top'
     */
    position;
    /**
     * Specifies the mouse action that triggers the Tooltip to show.
     *
     * @default 'hover'
     */
    showOn;
    /**
     * Specifies the delay in milliseconds before the Tooltip is shown.
     *
     * @default 100
     */
    showAfter;
    /**
     * @hidden
     */
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    constructor() { }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: TooltipSettings, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: TooltipSettings });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: TooltipSettings, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return []; } });
