/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { PreventableEvent } from "@progress/kendo-angular-common";
import { PopupRef } from "@progress/kendo-angular-popup";
/**
 * Provides arguments for the `show` event. The event fires when a popover is about to open. Cancel the event to prevent opening.
 */
export declare class PopoverShowEvent extends PreventableEvent {
    /**
     * Specifies the host element related to the Popover.
     */
    anchor: Element;
    /**
     * @hidden
     * Constructs the event arguments for the `show` event.
     * @param anchor - The host element related to the Popover.
     */
    constructor(anchor: Element);
}
/**
 * Provides arguments for the `hide` event. The event fires when a popover is about to close. Cancel the event to keep it open.
 */
export declare class PopoverHideEvent extends PreventableEvent {
    /**
     * Specifies the host element related to the Popover.
     */
    anchor: Element;
    /**
     * Specifies the Popover element.
     */
    popover: PopupRef;
    /**
     * @hidden
     * Constructs the event arguments for the `hide` event.
     * @param anchor - The host element related to the popover.
     * @param popover - The popover element.
     */
    constructor(anchor: Element, popover: PopupRef);
}
/**
 * Provides arguments for the `shown` event. The event fires after the Popover has opened and its opening animation has finished.
 */
export declare class PopoverShownEvent {
    /**
     * Specifies the host element related to the Popover.
     */
    anchor: Element;
    /**
     * Specifies the Popover element.
     */
    popover: PopupRef;
    /**
     * @hidden
     * Constructs the event arguments for the `shown` event.
     * @param anchor - The host element related to the popover.
     * @param popover - The popover element.
     */
    constructor(anchor: Element, popover: PopupRef);
}
/**
 * Provides arguments for the `hidden` event. The event fires after the popover has closed and its closing animation has finished.
 */
export declare class PopoverHiddenEvent {
    /**
     * Specifies the host element related to the Popover.
     */
    anchor: Element;
    /**
     * @hidden
     * Constructs the event arguments for the `hidden` event.
     * @param anchor - The host element related to the popover.
     */
    constructor(anchor: Element);
}
