/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { InjectionToken } from '@angular/core';
import { Position } from '../models/position.type';
import { ShowOption } from '../models/show.option.type';
import * as i0 from "@angular/core";
/**
 * Obsolete. Provide the TooltipSettings class instead.
 *
 * @hidden
 */
export declare const TOOLTIP_SETTINGS: InjectionToken<string>;
/**
 * Provides a global configuration for the Kendo UI Tooltip. Inject this class in the `AppComponent` constructor to override configuration properties.
 *
 * @example
 * ```typescript
 * import { TooltipSettings } from '@progress/kendo-angular-tooltip';
 *
 * @Component({
 *   selector: 'my-app',
 *   template: `<div kendoTooltip><button title="Save">Save</button></div>`,
 *   providers: [{
 *     provide: TooltipSettings,
 *     useFactory: (): TooltipSettings => ({ position: 'right' })
 *   }]
 * })
 * export class AppComponent {}
 * ```
 */
export declare class TooltipSettings {
    /**
     * Determines if the Tooltip displays a callout arrow.
     *
     * @default true
     */
    callout?: boolean;
    /**
     * Sets the title of the **Close** button.
     */
    closeTitle: string;
    /**
     * Specifies the position of the Tooltip relative to the anchor element.
     *
     * @default 'top'
     */
    position?: Position;
    /**
     * Specifies the mouse action that triggers the Tooltip to show.
     *
     * @default 'hover'
     */
    showOn?: ShowOption;
    /**
     * Specifies the delay in milliseconds before the Tooltip is shown.
     *
     * @default 100
     */
    showAfter?: number;
    /**
     * @hidden
     */
    constructor();
    static ɵfac: i0.ɵɵFactoryDeclaration<TooltipSettings, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<TooltipSettings>;
}
